@@ -1,7 +1,5 @@
-######################################################################
-#  This file should be kept compatible with Python 2.3, see PEP 291. #
-######################################################################
 import sys, os
+import contextlib
 
 # find_library(name) returns the pathname of a library, or None.
 if os.name == "nt":
@@ -92,7 +90,12 @@ elif sys.platform == "cygwin":
                 if not os.path.exists(implib):
                     continue
                 cmd = "dlltool -I " + implib + " 2>/dev/null"
-                res = os.popen(cmd).read().replace("\n","")
+                f = os.popen(cmd)
+                try:
+                    data = f.read()
+                finally:
+                    f.close()
+                res = data.replace("\n","")
                 if not res:
                     continue
                 return res
@@ -107,7 +110,7 @@ elif os.name == "posix":
         fdout, ccout = tempfile.mkstemp()
         os.close(fdout)
         cmd = 'if type gcc >/dev/null 2>&1; then CC=gcc; elif type cc >/dev/null 2>&1; then CC=cc;else exit 10; fi;' \
-              'LANG=C LC_ALL=C $CC -Wl,-t -o ' + ccout + ' 2>&1 -l' + name
+              '$CC -Wl,-t -o ' + ccout + ' 2>&1 -l' + name
         try:
             f = os.popen(cmd)
             try:
@@ -117,11 +120,11 @@ elif os.name == "posix":
         finally:
             try:
                 os.unlink(ccout)
-            except OSError, e:
+            except OSError as e:
                 if e.errno != errno.ENOENT:
                     raise
         if rv == 10:
-            raise OSError, 'gcc or cc command not found'
+            raise OSError('gcc or cc command not found')
         res = re.search(expr, trace)
         if not res:
             return None
@@ -134,11 +137,8 @@ elif os.name == "posix":
             if not f:
                 return None
             cmd = "/usr/ccs/bin/dump -Lpv 2>/dev/null " + f
-            f = os.popen(cmd)
-            try:
+            with contextlib.closing(os.popen(cmd)) as f:
                 data = f.read()
-            finally:
-                f.close()
             res = re.search(r'\[.*\]\sSONAME\s+([^\s]+)', data)
             if not res:
                 return None
@@ -154,12 +154,9 @@ elif os.name == "posix":
             dump = f.read()
             rv = f.close()
             if rv == 10:
-                raise OSError, 'objdump command not found'
-            f = os.popen(cmd)
-            try:
+                raise OSError('objdump command not found')
+            with contextlib.closing(os.popen(cmd)) as f:
                 data = f.read()
-            finally:
-                f.close()
             res = re.search(r'\sSONAME\s+([^\s]+)', data)
             if not res:
                 return None
@@ -178,51 +175,19 @@ elif os.name == "posix":
                     nums.insert(0, int(parts.pop()))
             except ValueError:
                 pass
-            return nums or [ sys.maxint ]
+            return nums or [ sys.maxsize ]
 
         def find_library(name):
             ename = re.escape(name)
             expr = r':-l%s\.\S+ => \S*/(lib%s\.\S+)' % (ename, ename)
-            f = os.popen('/sbin/ldconfig -r 2>/dev/null')
-            try:
+            with contextlib.closing(os.popen('/sbin/ldconfig -r 2>/dev/null')) as f:
                 data = f.read()
-            finally:
-                f.close()
             res = re.findall(expr, data)
             if not res:
                 return _get_soname(_findLib_gcc(name))
             res.sort(key=_num_version)
             return res[-1]
 
-    elif sys.platform == "sunos5":
-
-        def _findLib_crle(name, is64):
-            if not os.path.exists('/usr/bin/crle'):
-                return None
-
-            if is64:
-                cmd = 'env LC_ALL=C /usr/bin/crle -64 2>/dev/null'
-            else:
-                cmd = 'env LC_ALL=C /usr/bin/crle 2>/dev/null'
-
-            for line in os.popen(cmd).readlines():
-                line = line.strip()
-                if line.startswith('Default Library Path (ELF):'):
-                    paths = line.split()[4]
-
-            if not paths:
-                return None
-
-            for dir in paths.split(":"):
-                libfile = os.path.join(dir, "lib%s.so" % name)
-                if os.path.exists(libfile):
-                    return libfile
-
-            return None
-
-        def find_library(name, is64 = False):
-            return _get_soname(_findLib_crle(name, is64) or _findLib_gcc(name))
-
     else:
 
         def _findSoname_ldconfig(name):
@@ -242,11 +207,8 @@ elif os.name == "posix":
 
             # XXX assuming GLIBC's ldconfig (with option -p)
             expr = r'\s+(lib%s\.[^\s]+)\s+\(%s' % (re.escape(name), abi_type)
-            f = os.popen('/sbin/ldconfig -p 2>/dev/null')
-            try:
+            with contextlib.closing(os.popen('LC_ALL=C LANG=C /sbin/ldconfig -p 2>/dev/null')) as f:
                 data = f.read()
-            finally:
-                f.close()
             res = re.search(expr, data)
             if not res:
                 return None
@@ -261,15 +223,15 @@ elif os.name == "posix":
 def test():
     from ctypes import cdll
     if os.name == "nt":
-        print cdll.msvcrt
-        print cdll.load("msvcrt")
-        print find_library("msvcrt")
+        print(cdll.msvcrt)
+        print(cdll.load("msvcrt"))
+        print(find_library("msvcrt"))
 
     if os.name == "posix":
         # find and load_version
-        print find_library("m")
-        print find_library("c")
-        print find_library("bz2")
+        print(find_library("m"))
+        print(find_library("c"))
+        print(find_library("bz2"))
 
         # getattr
 ##        print cdll.m
@@ -277,18 +239,18 @@ def test():
 
         # load
         if sys.platform == "darwin":
-            print cdll.LoadLibrary("libm.dylib")
-            print cdll.LoadLibrary("libcrypto.dylib")
-            print cdll.LoadLibrary("libSystem.dylib")
-            print cdll.LoadLibrary("System.framework/System")
+            print(cdll.LoadLibrary("libm.dylib"))
+            print(cdll.LoadLibrary("libcrypto.dylib"))
+            print(cdll.LoadLibrary("libSystem.dylib"))
+            print(cdll.LoadLibrary("System.framework/System"))
         elif sys.platform == "cygwin":
-            print cdll.LoadLibrary("cygbz2-1.dll") 
-            print find_library("crypt")
-            print cdll.LoadLibrary("cygcrypt-0.dll") 
+            print(cdll.LoadLibrary("cygbz2-1.dll"))
+            print(find_library("crypt"))
+            print(cdll.LoadLibrary("cygcrypt-0.dll"))
         else:
-            print cdll.LoadLibrary("libm.so")
-            print cdll.LoadLibrary("libcrypt.so")
-            print find_library("crypt")
+            print(cdll.LoadLibrary("libm.so"))
+            print(cdll.LoadLibrary("libcrypt.so"))
+            print(find_library("crypt"))
 
 if __name__ == "__main__":
     test()
